write_rendered

Function write_rendered 

pub fn write_rendered(
    contents: &[u8],
    rel_path: &Path,
    output_dir: &Path,
    context: &TemplateContext,
) -> Result<PathBuf>
Render embedded template content and write the result to output_dir.

The .tera suffix is stripped from rel_path in the output.

Errors

Returns an error when the template fails to render or I/O fails.